<?php
class Person{
  public $id;
  public $field_int;
  public $field_str;


  public function __construct($id=NULL, $field_int=NULL, $field_str=NULL) {
    $this->id = $id === NULL ? $this->id : $id;
    $this->field_int = $field_int === NULL ? $this->field_int :$field_int;
    $this->field_str = $field_str === NULL ? $this->field_str :$field_str;
  }
}
class PdoKdbTest extends PHPUnit_Framework_TestCase
{
	public function testPdo_Connection_Success(){
		$dsn = 'kdb:host=192.168.28.36;dbname=postgres;port=6432';
		$user = 'system';
		$password = 'MANAGER';
		$dbh = null;
		try {
			$dbh = new PDO($dsn,$user, $password, array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION));
		} catch (Exception $e) {
			//echo 'Connection Failed: ' . $e->getMessage() ."\n";
		}
		$this->assertNotEmpty($dbh);
		return $dbh;
	}



	/**
	*@depends testPdo_Connection_Success
	*/
	public function testNoTableCreateTable($dbh){
		$table_name = 'testfetch';
		//$sql = 'SELECT * FROM USER_TABLES WHERE TABLE_NAME = :table_name';
		$stmt = $dbh->prepare('SELECT * FROM pg_tables WHERE tablename = :table_name');
		$stmt->execute(array(':table_name' => $table_name));
		$count = $stmt->rowCount();
		if(1 == $count)
		{
			$dbh->exec('drop table testfetch');
		}
		$stmt = $dbh->prepare('create table testfetch(name char(20), height int, is_child int)');
		$stmt->execute();

		$table_name = 'testtab1';
		$stmt = $dbh->prepare('SELECT * FROM pg_tables WHERE tablename = :table_name');
		$stmt->execute(array(':table_name' => $table_name));
		$count = $stmt->rowCount();
		if(1 == $count)
		{
			$dbh->exec('drop table testtab1');
		}
		$stmt = $dbh->prepare('create table testtab1(id int, t int)');
		$stmt->execute();
		for($ids = 1,$ts = 1; $ids <= 10; $ids++ )
		{
			$stmt = $dbh->prepare('insert into testtab1 values(:ids,:ts)');
			$stmt->execute(array(':ids' => $ids,':ts' => $ts));
			$ts++;
		}

		$table_name = 'testtab2';
		$stmt = $dbh->prepare('SELECT * FROM pg_tables WHERE tablename = :table_name');
		$stmt->execute(array(':table_name' => $table_name));
		$count = $stmt->rowCount();
		if(1 == $count)
		{
			$dbh->exec('drop table testtab2');
		}
		$stmt = $dbh->prepare('create table testtab2(id char(20),file_char char(20))');
		$stmt->execute();

		$table_name = 'testtab3';
		$stmt = $dbh->prepare('SELECT * FROM pg_tables WHERE tablename = :table_name');
		$stmt->execute(array(':table_name' => $table_name));
		$count = $stmt->rowCount();
		if(1 == $count)
		{
			$dbh->exec('drop table testtab3');
		}
		$stmt = $dbh->prepare('create table testtab3(id int, field_int int,field_str char(20))');
		$stmt->execute();
		for($ids = 1,$ts = 1,$str = 'test_parm'; $ids <= 10; $ids++ )
		{
			$stmt = $dbh->prepare('insert into testtab3 values(:ids,:ts,:str)');
			$stmt->execute(array(':ids' => $ids,':ts' => $ts,':str' => $str));
			$ts++;
		}

		$table_name = 'test_sequence';
		$stmt = $dbh->prepare('SELECT * FROM pg_tables WHERE tablename = :table_name');
		$stmt->execute(array(':table_name' => $table_name));
		$count = $stmt->rowCount();
		if(1 == $count)
		{
			$dbh->exec('drop table test_sequence');
		}
		$stmt = $dbh->prepare('create table test_sequence(id SERIAL,t int)');
		$stmt->execute();

		$table_name = 'testblob';
		$stmt = $dbh->prepare('SELECT * FROM pg_tables WHERE tablename = :table_name');
		$stmt->execute(array(':table_name' => $table_name));
		$count = $stmt->rowCount();
		if(1 == $count)
		{
			$dbh->exec('drop table testblob');
		}
		$stmt = $dbh->prepare('create table testblob(id int, bb blob, cb clob)');
		$stmt->execute();

		$table_name = 'test_new_data_type';
		$stmt = $dbh->prepare('SELECT * FROM pg_tables WHERE tablename = :table_name');
		$stmt->execute(array(':table_name' => $table_name));
		$count = $stmt->rowCount();
		if(1 == $count)
		{
			$dbh->exec('drop table test_new_data_type');
		}
		$stmt = $dbh->prepare('create table test_new_data_type(fnclob nclob, fbpcharbyte bpcharbyte, f_bpcharbyte _bpcharbyte, '.
			'fvarcharbyte varcharbyte, f_varcharbyte _varcharbyte, fora_date date)');
		$ret = $stmt->execute();
		$this->assertEquals(TRUE, $ret);
		$stmt = $dbh->prepare('insert into test_new_data_type values(:a,:b,:c,:d,:e,:f)');
		$stmt->execute(array(':a' => 'nclob string', ':b' => 'bpcharbyte string', ':c' => '{_bpcharbyte string}',
					':d' => 'varcharbyte string', ':e' => '{_varcharbyte string}', ':f' => '2020-02-22 13:28:32', ));
		$stmt = $dbh->prepare('SELECT * FROM test_new_data_type');
		$stmt->execute();
		$this->assertNotEquals(FALSE, $stmt->fetchAll());
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testTransaction($dbh){
		$ret = null;
		$ret = $dbh->beginTransaction();
		$this->assertEquals(TRUE, $ret);

		$rex = null;
		$rex = $dbh->inTransaction();
		$this->assertEquals(TRUE, $rex);

		$ret = null;
		$ret = $dbh->rollBack();
		$this->assertEquals(TRUE, $ret);

		$ret = $dbh->beginTransaction();
		$ret = null;
		$ret = $dbh->commit();
		$this->assertEquals(TRUE, $ret);

		$rex = null;
		$rex = $dbh->inTransaction();
		$this->assertEquals(FALSE, $rex);
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testError($dbh){
		try{
			$dbh->exec("INSERT INTO AK47 VALUES (1,1)");
		}catch(PDOException $e){

		}

		$ret = null;
		$ret =$dbh->errorcode();
		$this->assertNotNull($ret);

		$res = $dbh->errorinfo();
		$this->assertNotNull($res[2]);
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testExec($dbh){
		$sql_error = 'INSERT INTO BONNEX VALUES (1,1)';
		$sql_true = 'INSERT INTO testtab1 VALUES (1,1)';
		$sql_query = 'SELECT * FROM testtab1';

		$res = $dbh->exec($sql_true);
		$rex = $dbh->exec($sql_query);

		$this->assertEquals(1, $res);
		//$this->assertEquals(0, $rex);

		try{
			$dbh->exec($sql_error);
		}catch(PDOException $e){
		}
		$ret = $dbh->errorinfo();
		$this->assertContains('bonnex',$ret[2]);
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testSetAttribute($dbh){

		$ret = $dbh->setAttribute(PDO::ATTR_EMULATE_PREPARES, TRUE);
		$res = $dbh->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
		//$rex = $dbh->setAttribute(PDO::KDB_ATTR_DISABLE_NATIVE_PREPARED_STATEMENT, PDO::KDB_TRANSACTION_ACTIVE);

		$this->assertEquals(TRUE, $ret);
		$this->assertEquals(TRUE, $res);
		//$this->assertEquals(TRUE, $rex);
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testGetAttribute($dbh){
		$attributes = array(
    			"ERRMODE", "SERVER_INFO", "CLIENT_VERSION", "CONNECTION_STATUS", "SERVER_VERSION",
    			"ORACLE_NULLS", "PERSISTENT", "CASE" //,"TIMEOUT", "AUTOCOMMIT", "PREFETCH" //driver does not support these three attribute
		);

		foreach ($attributes as $val) {
    			$this->assertNotNull($dbh->getAttribute(constant("PDO::ATTR_$val")));
		}
		/**
		  *The properties of the following drive can be set, but can not be received by the property value
		  *	$this->assertNotNull($dbh->getAttribute(PDO::KDB_ATTR_DISABLE_NATIVE_PREPARED_STATEMENT));
		*/
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testgetAvailableDrivers($dbh){
		$this->assertContains('kdb',PDO::getAvailableDrivers());
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testPrepare($dbh){
		$sql = 'select id, t from testtab1 order by id';
		$stmt = $dbh->prepare($sql);
		$this->assertNotEquals(FALSE, $stmt);

		$stmt = FALSE;
		$stmt = $dbh->prepare($sql, array(PDO::ATTR_CURSOR => PDO::CURSOR_FWDONLY));
		$this->assertNotEquals(FALSE, $stmt);

		$stmt = FALSE;
		$stmt = $dbh->prepare($sql, array(PDO::ATTR_CURSOR => PDO::CURSOR_FWDONLY,PDO::ATTR_EMULATE_PREPARES => TRUE));
		$this->assertNotEquals(FALSE, $stmt);
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testLastInsertId($dbh){
		$last_insert_id = null;
		$last_id_no_name = null;
		$last_id_no_name = $dbh->lastInsertId();
		$this->assertNotNull($last_id_no_name);

		$dbh->exec('insert into test_sequence values(DEFAULT,2)');
		$dbh->exec('insert into test_sequence values(DEFAULT,3)');
		$last_insert_id = $dbh->lastInsertId('test_sequence_id_seq');
		$this->assertEquals(2,$last_insert_id);
	}


	/**
	*@depends testPdo_Connection_Success
	*/
	public function testQuote($dbh){
		$sql = "SELECT * FROM testtab1";
		$this->assertNotEquals(FALSE, $dbh->quote($sql, PDO::PARAM_STR));
		$this->assertNotEquals(FALSE, $dbh->quote($sql, PDO::PARAM_LOB));
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtExecute($dbh){
		$sql = "SELECT * FROM testtab1";
		$stmt = $dbh->prepare($sql);
		$this->assertEquals(TRUE, $stmt->execute());

		$sql = "DECLARE MycrsrVar  Cursor FOR SELECT * FROM testtab1";
		$stmt = null;
		$stmt = $dbh->prepare($sql);
		$dbh->beginTransaction();
		$this->assertEquals(TRUE, $stmt->execute());
		$dbh->rollBack();
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtBindParam($dbh){
		$sql = 'SELECT id,t FROM testtab1 WHERE id = :id AND t = :t';
		$stmt = $dbh->prepare($sql);
		$id = 4;
		$t = 5;
		$this->assertEquals(TRUE,$stmt->bindparam(':id', $id , PDO::PARAM_INT));
		$this->assertEquals(TRUE,$stmt->bindparam(':t', $id , PDO::PARAM_INT | PDO::PARAM_INPUT_OUTPUT, 12));
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtBindValue($dbh){
		$sql = 'SELECT id,t FROM testtab1 WHERE id = :id AND t = :t';
		$stmt = $dbh->prepare($sql);
		$this->assertEquals(TRUE,$stmt->bindvalue(':id', 4, PDO::PARAM_INT));
		$this->assertEquals(TRUE,$stmt->bindvalue(':t', 5 , PDO::PARAM_INT | PDO::PARAM_INPUT_OUTPUT));
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtBindColumn($dbh){
		$sql = 'SELECT * FROM testtab1';
		$stmt = $dbh->prepare($sql);
		$stmt->execute();
		$this->assertEquals(TRUE,$stmt->bindColumn('id', $id));
    		$this->assertEquals(TRUE,$stmt->bindColumn(2, $test));
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtBindAll($dbh){
		$sql = 'SELECT id,field_int,field_str FROM testtab3 WHERE id = :id AND field_int = :t AND field_str = :str';
		$stmt = $dbh->prepare($sql);
		$id = 4;
		$str = 'databasexxx';
		$this->assertEquals(TRUE,$stmt->bindparam(':str', $str , PDO::PARAM_STR));
		$this->assertEquals(TRUE,$stmt->bindparam(':id', $id , PDO::PARAM_INT));
		$this->assertEquals(TRUE,$stmt->bindvalue(':t', 5 , PDO::PARAM_INT | PDO::PARAM_INPUT_OUTPUT));
		$stmt->execute();
		$this->assertEquals(TRUE,$stmt->bindColumn('id', $number));
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtCloseCursor($dbh){
		$sql = 'SELECT * FROM testtab1';
		$stmt = $dbh->prepare($sql);
		$this->assertEquals(TRUE,$stmt->closeCursor());
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtColumnCount($dbh){
		$sql = 'SELECT * FROM testtab1';
		$stmt = $dbh->prepare($sql);
		$stmt->execute();
		$this->assertGreaterThan(0, $stmt->columnCount());
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtError($dbh){
		$sql = 'SELECT * FROM cockcn';
		$stmt = $dbh->prepare($sql);
		try{
			$stmt->execute();
		}catch(Exception $e) {
			//
		}
		$ret = $stmt->errorInfo();
		$this->assertContains('cockcn', $ret[2]);
		$res = $stmt->errorCode ();
		$this->assertNotNull($res);
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtGetColumnMeta($dbh){
		$sql = 'SELECT * FROM testtab1';
		$stmt = $dbh->prepare($sql);
		$stmt->execute();
		$ret = null;
		$rex = null;
		$rex = $stmt->getColumnMeta(0);
		$this->assertNotNull($rex);
		$ret = $stmt->getColumnMeta(1);
		$this->assertNotNull($ret);

	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtFetchType($dbh){
		$sql = 'SELECT * FROM testtab3 order by id';
		$stmt = $dbh->prepare($sql,array(PDO::ATTR_CURSOR => PDO::CURSOR_SCROLL));
		$stmt->execute();
		$this->assertNotEquals(FALSE, $stmt->fetch(PDO::FETCH_ASSOC));
		$this->assertNotEquals(FALSE, $stmt->fetch(PDO::FETCH_BOTH));
		$this->assertNotEquals(FALSE, $stmt->fetch(PDO::FETCH_LAZY));
		$this->assertNotEquals(FALSE, $stmt->fetch(PDO::FETCH_OBJ));

		/*
		print_r($stmt->fetch(PDO::FETCH_ASSOC));
		print_r($stmt->fetch(PDO::FETCH_BOTH));
		print_r($stmt->fetch(PDO::FETCH_LAZY));
		print_r($stmt->fetch(PDO::FETCH_OBJ));
		*/
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtFetchmode($dbh){
		$sql = 'SELECT * FROM testtab3 order by id';
		$stmt = $dbh->prepare($sql,array(PDO::ATTR_CURSOR => PDO::CURSOR_SCROLL));
		$stmt->execute();
		$array = array();
		$obj = new person();
		$this->assertEquals(TRUE,$stmt->setFetchMode(PDO::FETCH_NUM));
		$this->assertEquals(TRUE,$stmt->setFetchMode(PDO::FETCH_COLUMN, 1));
		$this->assertEquals(TRUE,$stmt->setFetchMode(PDO::FETCH_CLASS, 'person', $array));
		$this->assertEquals(TRUE,$stmt->setFetchMode(PDO::FETCH_INTO, $obj));
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtFetchAll($dbh){
		$sql = 'SELECT * FROM testtab3 order by id';
		$stmt = $dbh->prepare($sql);
		$stmt->execute();
		$this->assertNotEquals(FALSE,$stmt->fetchAll());
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtFetchObject($dbh){
		$sql = 'SELECT * FROM testtab3 order by id';
		$stmt = $dbh->prepare($sql);
		$stmt->execute();
		$this->assertNotEquals(FALSE,$stmt->fetchObject('Person'));

	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtFetchColumn($dbh){
		$sql = 'SELECT * FROM testtab3 order by id';
		$result = null;
		$stmt = $dbh->prepare($sql);
		$stmt->execute();
		$result = $stmt->fetchColumn();
		$this->assertNotNull($result);
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtrowCount($dbh){
		$sql = 'SELECT * FROM testtab3 order by id';
		$result = null;
		$stmt = $dbh->prepare($sql);
		$stmt->execute();
		$result = $stmt->rowCount();
		$this->assertEquals(10,$result);
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmt_InsertrowCount($dbh){
		$sql = 'insert into testtab3 values(11,11,\'rowcount\')';
		$result = null;
		$stmt = $dbh->query($sql);
		$result = $stmt->fetch();
		$this->assertNotEquals(null,$result);
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmt_InsertQuery($dbh){
		$sql = 'insert into testtab3 values(11,11,\'rowcount\')';
		$result = null;
		$stmt = $dbh->query($sql);
		$result = $stmt->fetch();
		$this->assertNotEquals(null,$result);
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	//this stmt->NextRowset is special function,our database is not supported.
	/*public function testStmtNextRowset($dbh){
		$sql = 'SELECT * FROM testtab3 order by id';
		$stmt = $dbh->prepare($sql);
		$stmt->execute();
		$stmt->fetchAll();
		//$stmt->nextRowset();
		$this->assertEquals(TRUE,$stmt->nextRowset());
	}*/

	/**
	*@depends testPdo_Connection_Success
	*/
	//this stmt->get(set)Attribute is special function,our database is not supported.
	/*
	public function testStmtGetAttribute($dbh){
		$sql = 'SELECT * FROM testtab3 order by id';
		$result = null;
		$stmt = $dbh->prepare($sql);
		$stmt->execute();
		$result = $stmt->getAttribute(PDO::ATTR_CURSOR_NAME);
		$this->assertNotNull($result);
	}
	*/


	/**
	*@depends testPdo_Connection_Success
	*/
	/*public function testLob($dbh){
		$dbh->beginTransaction();

		$oid = $dbh->kdbLOBCreate();
		$this->assertNotEquals(FALSE, $oid);

		$stream = $dbh->kdbLOBOpen($oid, 'w');
		$this->assertNotEquals(FALSE, $stream);

		$local = fopen("/home/yubo/Downloads/phpunit/test.jpg", 'rb');
		stream_copy_to_stream($local, $stream);

		$stmt = $dbh->prepare("INSERT INTO testfetch VALUES (?, 180, 1, ?)");
		$local = null;
		$stream = null;
		$name = 'DAMI';
		$this->assertEquals(TRUE,$stmt->execute(array($name, $oid)));

		$dbh->commit();

		$dbh->beginTransaction();

		$name = 'DAMI';
		$oid = $dbh->kdbLOBCreate();
		//$this->assertNotEquals(FALSE, $oid);

		$this->assertNotEquals(FALSE, $dbh->kdbLOBUnlink($oid));
		$stmt = $dbh->prepare("DELETE FROM testfetch where NAME = :name");
		$stmt->execute(array(':name' => $name));

		$dbh->commit();
	}*/

    /**
	*@depends testPdo_Connection_Success
	*/
	public function testblob($dbh){
		$stmt = $dbh->prepare("insert into testblob (id, bb, cb) " ."VALUES (?, ?, ?)");

		$id=1;
		$fp = fopen("blob.jpg", "rb") or die("Unable to open file!");
		$fp2 = "clob test,aaaaaaaaaaaaaaaaaaaaaaaabbbbbbbbbbbbbbbbbbbbbbbbbbbcccccccccccccccccdddddddddddddddd";
		$stmt->bindParam(1, $id);
		$stmt->bindParam(2, $fp, PDO::PARAM_LOB);
		$stmt->bindParam(3, $fp2, PDO::PARAM_STR,strlen($fp2));

		$dbh->beginTransaction();
		$stmt->execute();
		$dbh->commit();
		fclose($fp);


		$stmt = $dbh->prepare("select bb, cb from testblob where id=1");
		$stmt->execute();
		$stmt->bindColumn(1, $bb, PDO::PARAM_LOB);
		$stmt->bindColumn(2, $cb, PDO::PARAM_LOB);
		$stmt->fetch(PDO::FETCH_BOUND);

		$fp = fopen("blob.jpg", "rb") or die("Unable to open file!");
		$fp_read = "";
		while (!feof($fp)) {
			$fp_read .= fread($fp, 1024);
		}

		$this->assertEquals($cb,$fp2);
		//输出至终端
		//fpassthru($bb);
		//blob
		$wblobfp = fopen("blob_out.jpg", "wb+");
		stream_copy_to_stream($bb, $wblobfp);

		//clob
		$wclobfp = fopen("testclob_out.log", "w+");
		fwrite($wclobfp, $cb);

		fclose($wblobfp);
		fclose($wclobfp);
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testStmtFetchCursorOrientation($dbh){
		$sql = 'SELECT * FROM testtab3';
		$stmt = $dbh->prepare($sql, array(PDO::ATTR_CURSOR => PDO::CURSOR_SCROLL));
		$stmt->execute();
		$this->assertNotEquals(FALSE, $stmt->fetch(PDO::FETCH_NUM, PDO::FETCH_ORI_NEXT));
		$this->assertNotEquals(FALSE, $stmt->fetch(PDO::FETCH_NUM, PDO::FETCH_ORI_LAST));
		$this->assertNotEquals(FALSE, $stmt->fetch(PDO::FETCH_NUM, PDO::FETCH_ORI_PRIOR));
		$this->assertNotEquals(FALSE, $stmt->fetch(PDO::FETCH_NUM, PDO::FETCH_ORI_FIRST));
		$this->assertNotEquals(FALSE, $stmt->fetch(PDO::FETCH_NUM, PDO::FETCH_ORI_ABS, 1));
		$this->assertNotEquals(FALSE, $stmt->fetch(PDO::FETCH_NUM, PDO::FETCH_ORI_REL, 1));

	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testPdoCopyFrom($dbh){
		$tableName = 'testtab1';
		$rows = array( 200,201);
		$row[] = implode("\t", $rows) . "\n";
		$this->assertEquals(TRUE,$dbh->kdbCopyFromArray($tableName, $row));


		$tableName1 = 'testtab2';
		$myfile = fopen("php_pdo_test.txt", "w+",0777) or die("Unable to open file!");
		$txt = "abc\tbbq\nrag\tcfg";
		fwrite($myfile, $txt);
		$this->assertEquals(TRUE,$dbh->kdbCopyFromFile($tableName1, "php_pdo_test.txt","\t"));
		fclose($myfile);
	}

	/**
	*@depends testPdo_Connection_Success
	*/
	public function testPdoCopyTo($dbh){
		$tableName = 'testtab1';
		$this->assertNotNull($dbh->kdbCopyToArray($tableName, "\t"));

		$tableName1 = 'testtab2';
		$myfile = fopen("php_pdo_test1.txt", "w+",0777) or die("Unable to open file!");
		$this->assertEquals(TRUE,$dbh->kdbCopyToFile($tableName1, "php_pdo_test1.txt","\t"));
		$this->assertNotEquals(0,filesize ("php_pdo_test1.txt"));
		fclose($myfile);
	}
}
